Title: [154362] trunk/Source/_javascript_Core
Revision
154362
Author
achristen...@apple.com
Date
2013-08-20 15:03:39 -0700 (Tue, 20 Aug 2013)

Log Message

Compile fix for Win64 after r154156.

Rubber stamped by Oliver Hunt.

* jit/JITStubsMSVC64.asm:
Renamed ctiVMThrowTrampolineSlowpath to ctiVMHandleException and
cti_vm_throw_slowpath to cti_vm_handle_exception.

Modified Paths

Diff

Modified: trunk/Source/_javascript_Core/ChangeLog (154361 => 154362)


--- trunk/Source/_javascript_Core/ChangeLog	2013-08-20 21:58:26 UTC (rev 154361)
+++ trunk/Source/_javascript_Core/ChangeLog	2013-08-20 22:03:39 UTC (rev 154362)
@@ -1,5 +1,15 @@
 2013-08-20  Alex Christensen  <achristen...@apple.com>
 
+        Compile fix for Win64 after r154156.
+
+        Rubber stamped by Oliver Hunt.
+
+        * jit/JITStubsMSVC64.asm:
+        Renamed ctiVMThrowTrampolineSlowpath to ctiVMHandleException and
+        cti_vm_throw_slowpath to cti_vm_handle_exception.
+
+2013-08-20  Alex Christensen  <achristen...@apple.com>
+
         <https://webkit.org/b/120076> More work towards a Win64 build
 
         Reviewed by Brent Fulgham.

Modified: trunk/Source/_javascript_Core/jit/JITStubsMSVC64.asm (154361 => 154362)


--- trunk/Source/_javascript_Core/jit/JITStubsMSVC64.asm	2013-08-20 21:58:26 UTC (rev 154361)
+++ trunk/Source/_javascript_Core/jit/JITStubsMSVC64.asm	2013-08-20 22:03:39 UTC (rev 154362)
@@ -24,7 +24,7 @@
 ;*/
 
 EXTERN cti_vm_throw : near
-EXTERN cti_vm_throw_slowpath : near
+EXTERN cti_vm_handle_exception : near
 PUBLIC ctiTrampoline
 PUBLIC ctiVMThrowTrampoline
 PUBLIC ctiOpThrowNotCaught
@@ -69,17 +69,17 @@
     int 3
 ctiVMThrowTrampoline ENDP
 
-ctiVMThrowTrampolineSlowpath PROC
+ctiVMHandleException PROC
 	sub rsp, 16
     mov rcx, rsp
 	mov rdx, r13
-	call cti_vm_throw_slowpath
-    ; When cti_vm_throw_slowpath returns, rax points to the memory we allocated on stack
+	call cti_vm_handle_exception
+    ; When cti_vm_handle_exception returns, rax points to the memory we allocated on stack
 	; It contains the callFrame and handler address
 	pop rax		; callFrame
 	pop rdx		; handler
     jmp rdx
-ctiVMThrowTrampolineSlowpath ENDP
+ctiVMHandleException ENDP
  
 ctiOpThrowNotCaught PROC
     add rsp, 58h
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to